<?php

require_once "config.inc";
require_once "constants.inc";
require_once "db.inc";
require_once "error.inc";

//<-----
//	Functions:		Text				Bit
//					ENABLE				1
//					BORROW/RETURN		2
//					BORROWED_BOOKS		3
//					ADD/EDIT			4
//					DELETE				5
//					USER_MANAGEMENT		6
//----->

function check_priv($query, $userid = USER_ID)
{
	switch(strtoupper(trim($query)))
	{
		case "ENABLE":
			$priv = 1;
			break;

		case "BORROW":
			$priv = 2;
			break;

		case "RETURN":
			$priv = 2;
			break;

		case "BORROWED_BOOKS":
			$priv = 4;
			break;

		case "ADD":
			$priv = 8;
			break;

		case "EDIT":
			$priv = 8;
			break;

		case "DELETE":
			$priv = 16;
			break;

		case "GROUP_MANAGEMENT":
			$priv = 32;
			break;

		case "NORMAL":
			$cast = "NORMAL";
			break;

		case "POWER":
			$cast = "POWER";
			break;

		case "ADMIN":
			$cast = "ADMIN";
			break;

		case "DISTRO":
			//return 1; //debugging ONLY!!
			$distro = "YES";
			break;

		case "LABEL_PRINTER":
			$printer = "LABEL";
			break;

		case "RECEIPT_PRINTER":
			$printer = "RECEIPT";
			break;

		default:
			print $query;
			$priv = 0;
			error("unknown priv");
			break;
	}

	if($userid == USER_ID)
	{
		$user_privileges = USER_PRIVILEGES;
		$user_cast = USER_CAST;
	}
	else
	{
		$sql = "SELECT user_privileges, user_cast FROM users WHERE user_id=" . $userid;
		$sqlResult = mysql_query($sql);
		$row = mysql_fetch_array($sqlResult);

		$user_privileges = $row['user_privileges'];
		$user_cast = $row['user_cast'];
	}

	if(isset($priv))
	{
		if ($priv & $user_privileges)
			return 1;
		else
			return 0;
	}
	elseif(isset($cast))
	{
		if ($cast == $user_cast)
			return 1;
		else
			return 0;
	}
	elseif(isset($distro))
	{
		if (checkUA() && checkIP())
			return 1;
		else
			return 0;
	}
	elseif(isset($printer))
	{
		//check_priv('DISTRO') already checks IP,
		//but it's performed again in case code changes
		if (check_priv('DISTRO') && checkIP() && check_printer($printer))
			return 1;
		else
			return 0;
	}

	return 0;
}

function set_priv($priv1, $priv2 = "", $priv3 = "", $priv4 = "", $priv5 = "", $priv6 = "", $priv7 = "", $priv8 = "")
{
	$priv = array($priv1, $priv2, $priv3, $priv4, $priv5, $priv6, $priv7, $priv8);
	$newpriv = 0;
	foreach($priv as $cp)
	{
		switch($cp)
		{
			case "ENABLE":
				$newpriv += 1;
				break;

			case "BORROW":
				$newpriv += 2;
				break;

			case "RETURN":
				$newpriv += 2;
				break;

			case "BORROWED_BOOKS":
				$newpriv += 4;
				break;

			case "ADD":
				$newpriv += 8;
				break;

			case "EDIT":
				$newpriv += 8;
				break;

			case "DELETE":
				$newpriv += 16;
				break;

			case "GROUP_MANAGEMENT":
				$newpriv += 32;
				break;
		}
	}

	return $newpriv;
}

//<----
//	bool has_page_priv(string page_ident)
//---->
function has_page_priv($page_ident = '')
{
	global $PageID;

	if ($page_ident == '') {
		$page_ident = $PageID;
	}

	$prefs = get_page_config(array(), $page_ident);
	$perms = $prefs['permissions'];

	if ($perms != '')
	{
		if (is_array($perms))
		{
			foreach ($perms as $priv)
			{
				if (sizeof($tmp = explode(' ', $priv)) > 1) {
					foreach ($tmp as $p) {
						if (check_priv(trim($p))) {
							return TRUE;
						}
					}
					return FALSE; //else
				}
				elseif (!check_priv($priv)) {
					return FALSE;
				}
			}
		}
		else
		{
			if (sizeof($tmp = explode(' ', $perms)) > 1) {
				foreach ($tmp as $p) {
					if (check_priv(trim($p))) {
						return TRUE;
					}
				}
				return FALSE; //else
			}
			elseif (!check_priv($perms)) {
				return FALSE;
			}
		}
	}

	return TRUE;
}

//<----
//	bool has_category_priv(int number)
//---->
function has_category_priv($number)
{
	global $site_config;

	foreach ($site_config[$number] as $page_ident)
	{
		$pageconf = get_page_config(array(), $page_ident);

		//if ANY page in this section is allowed, the category is allowed
		//unless it is a page that loads outside the main layout
		if (has_page_priv($page_ident) && $pageconf['menu_target'] != '_blank') {
			return TRUE;
		}
	}

	return FALSE; //if nothing has been returned before this
}

function checkIP()
{
	global $config;
	static $checked;

	//IP does not change during same request
	if ($checked == 1) {
		return 1;
	}

	$checked = 1;

	if ($config['ip_check'] == 1)
	{
		$ip = $_SERVER['REMOTE_ADDR'];
		$allowed = explode(",", $config['ip_allowed']);

		foreach ($allowed as $current)
		{
			if ($ip == trim($current)) return 1;
		}

		return 0;
	}
	else
	{
		return 1;
	}
}

function checkUA()
{
	global $config;

	if ($config['using_distro'] == 1)
	{
		if($_SERVER['HTTP_USER_AGENT'] == $config['distro_user_agent'])
			return 1;
		else
			return 0;
	}
	else
	{
		return 1;
	}
}

function check_printer($type)
{
	global $config;

	return $config[strtolower($type) . '_printer'];
}

function my_subordinate($user_id, $who = USER_ID)
{
	if(check_priv("GROUP_MANAGEMENT"))
	{
		if(check_priv("ADMIN"))
		{
			return 1;
		}
		elseif(check_priv("POWER"))
		{
			if(check_priv("ADMIN", $user_id))
				return 0;

           	$res = mysql_query(	"SELECT *
								FROM linkage
								WHERE user_id=$user_id && group_id IN
									(SELECT group_id
									FROM linkage
									WHERE group_manager=1 && user_id=$who)
								");

			/*
			This has been left here to show how _NOT_ to make a check:
			the result of this while is a dead mysql-loop which results
			in the crash of the mysql server. Way to go, Lanttis...=)
			
			while($groups = mysql_fetch_array(mysql_query("SELECT group_id FROM linkage WHERE group_manager=1 && user_id=".$who)))
			{
				if(mysql_num_rows(mysql_query("SELECT user_id FROM linkage WHERE user_id=".$user_id." && group_id=".$groups['group_id'])))
				{
					return 1;
				}
			}*/

			if(mysql_num_rows($res)) {
				return 1;
			} else {
				return 0;
			}
		}
		else
		{
			return 0;
		}
	}
	else
	{
		return 0;
	}
}

?>
